Tutorial Guide
**************

We think, that the easiest way to learn is learning-by-doing. For this, the following example will introduce you to the
most important components of the Balder system, by creating Balder tests for an example project which you can find in
many projects and companies.

But before you start, make sure that you have read the `Getting Started Guide <Getting Started>`_, because this guide
explains the basic concepts of Balder.

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    00_intro.rst
    01_develop_first_test.rst
    02_install_first_web_tests.rst
    03_port_web_tests_to_cli.rst
